import 'package:flutter/material.dart';
import '../models/user_model.dart';
import '../services/user_service.dart';

class UserManagementViewModel extends ChangeNotifier {
  final UserService _userService;
  List<UserModel> _users = [];
  bool _isLoading = false;

  List<UserModel> get users => _users;
  bool get isLoading => _isLoading;

  UserManagementViewModel(this._userService);

  Future<void> fetchUsers() async {
    _isLoading = true;
    notifyListeners();

    _users = await _userService.fetchUsers();

    _isLoading = false;
    notifyListeners();
  }

  Future<void> updateUser(UserModel user) async {
    await _userService.updateUser(user);
    fetchUsers();
  }

  Future<void> deleteUser(String uid) async {
    await _userService.deleteUser(uid);
    fetchUsers();
  }

  Future<void> resetPassword(String email) async {
    await _userService.resetPassword(email);
  }
}
